@@ -37,7 +37,6 @@
 #include <QUrl>
 #include <QProcess>
 #include <QRegularExpression>
-#include <QTimer>
 
 #include <iostream>
 #include <memory>
@@ -595,12 +594,14 @@ int main(int argc, char *argv[])
             h = args.at(1).toInt();
         }
 
-        return Widgets::textBox(nullptr, w, h, title, parser.value(QStringLiteral("textbox")));
+        const bool retcode = Widgets::textBox(nullptr, w, h, title, parser.value(QStringLiteral("textbox")));
+        return retcode ? 0 : 1;
     }
 
     // --imgbox <file>
     if (parser.isSet(QStringLiteral("imgbox"))) {
-        return Widgets::imgBox(nullptr, title, parser.value(QStringLiteral("imgbox")));
+        const bool retcode = Widgets::imgBox(nullptr, title, parser.value(QStringLiteral("imgbox")));
+        return retcode ? 0 : 1;
     }
 
     // --imginputbox <file> [text]
@@ -633,9 +634,9 @@ int main(int argc, char *argv[])
         }
 
         QString result;
-        int ret = Widgets::textInputBox(nullptr, w, h, title, Utils::parseString(parser.value(QStringLiteral("textinputbox"))), init, result);
+        const bool retcode = Widgets::textInputBox(nullptr, w, h, title, Utils::parseString(parser.value(QStringLiteral("textinputbox"))), init, result);
         cout << qPrintable(result) << endl;
-        return ret;
+        return retcode ? 0 : 1;
     }
 
     // --combobox <text> item [item] ..."
@@ -1007,7 +1008,7 @@ int main(int argc, char *argv[])
             if (returnCode) {
                 cout << result << endl;
             }
-            return returnCode;
+            return returnCode ? 0 : 1;
         } else {
             cerr << qPrintable(i18n("Syntax: --slider <text> <min> <max> <step>")) << endl;
             return -1;
@@ -1035,7 +1036,7 @@ int main(int argc, char *argv[])
         if (returnCode) {
             cout << result.toString(dateFormat).toLocal8Bit().data() << endl;
         }
-        return returnCode;
+        return returnCode ? 0 : 1;
     }
 
     parser.showHelp();
